# author: Oliver Glant
# email: oliver.glant@gmail.com
# Eon IV injuries roller

from eon4dice import roll
from eon4injuries.Skadetabell import Skadetabell


class InjuryRoller:
    def __init__(self):
        self.skadetabell = Skadetabell()

    def injury_effects(self, damage, damagetable, table_modifier=0, verbose=True):
        """
        Funktionen tar skadeverkan och skadetyp och fastställer effekterna av skadan.

        Parametern table_modifier är eventuella modifikationer på tabellslaget från t ex vapenegenskap

        Returnerar en lista
        """
        effects = [0, 0, '']  # utmattning, dödsslag, beskrivning

        # beräkna utmattning
        if damage > 0:
            if damage < 5:
                effects[0] = 1
            else:
                effects[0] = int((damage - damage % 5) / 2.5)
        if verbose:
            print('Utmattning:', effects[0])
        # Skadetabell
        if damage > 9:
            table_roll = roll('1T10') + (effects[0] - 4) + table_modifier
            result = table_roll  # används för att beräkna dödsslag om resultatet är över 20
            if table_roll > 20:
                table_roll = 20
            elif table_roll < 1:
                table_roll = 1
            effects[2] = self.skadetabell.table[damagetable][table_roll]
            if verbose:
                print(f'{damagetable}{f" (mod: {table_modifier:+})" if table_modifier != 0 else ""}:'
                      f' {effects[2]}(resultat: {result})')

        return effects


from unittest import TestCase

from eon4injuries import injuries


class TestInjuryRoller(TestCase):
    def test_injury_effects(self):
        injuryroller = injuries.InjuryRoller()
        roll1 = injuryroller.injury_effects(13, 'Slagsmålsskada mot huvud', 1, verbose=True)
        print(roll1)
        self.assertEqual(len(roll1), 3, msg='Injury result is not a list of length 3')



# author: Oliver Glant
# email: oliver.glant@gmail.com
# Eon IV injury tables

import os
import importlib.resources as pkg_resources


class Skadetabell:
    table = {}
    content_list = []

    def __init__(self):
        filename = 'skadetabell.txt'

        # Check current directory first
        if os.path.isfile(filename):
            file_path = filename
        else:
            # If not found, check the eon4injuries package
            if pkg_resources.is_resource('eon4injuries', filename):
                with pkg_resources.path('eon4injuries', filename) as package_path:
                    file_path = str(package_path)
            else:
                raise FileNotFoundError(f"{filename} not found in the current directory or the eon4injuries package.")

        with open(file_path, 'r', encoding="utf-8") as file:
            current_table = []
            nameflag = True
            for line in file.readlines():
                if line.strip() == 'XXX':
                    nameflag = True  # True om nästa rad är namnet på tabellen
                    table_name = current_table[0].strip()
                    self.content_list.append(table_name)
                    table_contents = current_table[0:]
                    self.table[table_name] = table_contents
                    current_table = []
                elif line[0].isdigit() or nameflag:
                    current_table.append(line)
                    nameflag = False
                else:
                    current_table[-1] = current_table[-1] + ' ' + line

